class Materials:
    def __init__(self, Rth, Cth):
        """
        Initializes an instance of the Materials class.

        Parameters:
        Rth (float): Thermal resistance value
        Cth (float): Thermal capacitance value
        """
        self.Rth = Rth  # Assign thermal resistance
        self.Cth = Cth  # Assign thermal capacitance
